==> org-lsst-ccs-messaging-jms-2.0.2-sources.jar: org/lsst/ccs/messaging/jms/TopicContextFactory.java <==
package org.lsst.ccs.messaging.jms;

import org.lsst.ccs.utilities.logging.Logger;
import javax.naming.Context;
import javax.naming.InitialContext;
import javax.naming.NamingException;
import javax.jms.ConnectionFactory;
import javax.jms.Topic;
import javax.jms.Session;
import javax.jms.Connection;
import java.util.Properties;
import javax.jms.JMSException;
import javax.jms.MessageConsumer;
import org.lsst.ccs.bootstrap.BootstrapResourceUtils;
import org.lsst.ccs.messaging.MessagingAccessLayer.BusAccess;

/**
 *
 * @author emarin
 */
public class TopicContextFactory {
    static protected TopicContextFactory instance = null;
    
    public static synchronized TopicContextFactory getTopicContextFactory() {
        if (instance == null) {
            instance = new TopicContextFactory();
        }
        return instance;
    }
    
    static Logger log = Logger.getLogger("org.lsst.ccs.bus.jms.TopicSessionFactory");
    
    Context context;
    
    ConnectionFactory tcf;

    //JMX
//    private AdminConnectionFactory acf = new AdminConnectionFactory();
//    private JMXConnector jmxc;
//    private MBeanServerConnection mbsc;
    
    Topic statusTopic;
    Topic commandTopic;
    Topic logTopic;
    
    public void reset() {
        context = null;
        tcf = null;
        commandTopic = null;
        logTopic = null;
        statusTopic = null;
    }
    
    public synchronized void getTopicContext() {
        try {
//            if (jmxc == null){
//                jmxc = acf.createConnection();
//                mbsc = jmxc.getMBeanServerConnection();
//            }
            if (context == null) {
                Properties props = BootstrapResourceUtils.getBootstrapProperties("jndi");
                context = new InitialContext(props);
            }
            if (tcf == null) {
                tcf = (ConnectionFactory) context.lookup("ConnectionFactory");
            }
             if (commandTopic == null) {
                log.info("lookup topic/control/command");
                commandTopic = (Topic) context.lookup("topic/control/command");
                
            }
            if (statusTopic == null) {
                log.info("lookup topic/control/status");
                statusTopic = (Topic) context.lookup("topic/control/status");
                
            }
            if (logTopic == null) {
                log.info("lookup topic/control/log");
                logTopic = (Topic) context.lookup("topic/control/log");
                
            }
            // Destroy all existing connections (just in case)
           
            
            
        } catch (NamingException e1) {
            e1.printStackTrace();
            throw new RuntimeException(e1);
//        } catch (JMException ex) {
//            log.error(TopicContextFactory.class.getName());
//            throw new RuntimeException(ex);
//        } catch (IOException ex) {
//            log.error(TopicContextFactory.class.getName());
//            throw new RuntimeException(ex);
        } 
    }
    
    public synchronized Session createSession(String agentName) throws JMSException{
        if (tcf == null){
            getTopicContext();
        }
        Connection connection = tcf.createConnection();
        connection.setClientID(agentName);
        connection.start();
        Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
        return session;
    }
    
    
    public synchronized Topic getCommandTopic() {
        if (commandTopic == null) {
            getTopicContext();
        }
        return commandTopic;
    }
    
    public synchronized Topic getStatusTopic() {
        if (statusTopic == null) {
            getTopicContext();
        }
        return statusTopic;
    }
    
    public synchronized Topic getLogTopic() {
        if (logTopic == null) {
            getTopicContext();
        }
        return logTopic;
    }
    
    public synchronized Topic getTopic(String topic){
        switch (topic){
            case "LOG":
                return getLogTopic();
            case "STATUS":
                return getStatusTopic();
            case "COMMAND":
                return getCommandTopic();
            default :
                return null;
        }
    }
    
    public MessageConsumer getSubscriber(Session session, String agentName, BusAccess busAccess, String messageSelector){
        try {
            switch (busAccess.getBus().ordinal()){
                case 0:
                return session.createConsumer(logTopic, messageSelector, false);
                case 1:
                return session.createConsumer(statusTopic, messageSelector, false);
                case 2:
                return session.createConsumer(commandTopic, messageSelector, false);
            }
            return null; // Todo : change that
        } catch (JMSException ex) {
            throw new RuntimeException(ex);
        }
    }
    
    
//    public MBeanServerConnection getMBeanServerConnection(){
//        if (mbsc == null){
//            getTopicContext();
//        }
//        return mbsc;
//    }
}

==> org-lsst-ccs-messaging-jms-4.0.8-sources.jar: org/lsst/ccs/messaging/jms/TopicContextFactory.java <==
package org.lsst.ccs.messaging.jms;

import org.lsst.ccs.utilities.logging.Logger;
import javax.naming.Context;
import javax.naming.InitialContext;
import javax.naming.NamingException;
import javax.jms.ConnectionFactory;
import javax.jms.Topic;
import javax.jms.Session;
import javax.jms.Connection;
import java.util.Properties;
import javax.jms.JMSException;
import javax.jms.MessageConsumer;
import org.lsst.ccs.bootstrap.BootstrapResourceUtils;
import org.lsst.ccs.messaging.MessagingAccessLayer.BusAccess;

/**
 *
 * @author emarin
 */
public class TopicContextFactory {
    static protected TopicContextFactory instance = null;
    
    public static synchronized TopicContextFactory getTopicContextFactory() {
        if (instance == null) {
            instance = new TopicContextFactory();
        }
        return instance;
    }
    
    static Logger log = Logger.getLogger("org.lsst.ccs.bus.jms.TopicSessionFactory");
    
    Context context;
    
    ConnectionFactory tcf;

    //JMX
//    private AdminConnectionFactory acf = new AdminConnectionFactory();
//    private JMXConnector jmxc;
//    private MBeanServerConnection mbsc;
    
    Topic statusTopic;
    Topic commandTopic;
    Topic logTopic;
    
    public void reset() {
        context = null;
        tcf = null;
        commandTopic = null;
        logTopic = null;
        statusTopic = null;
    }
    
    public synchronized void getTopicContext() {
        try {
//            if (jmxc == null){
//                jmxc = acf.createConnection();
//                mbsc = jmxc.getMBeanServerConnection();
//            }
            if (context == null) {
                Properties props = BootstrapResourceUtils.getBootstrapProperties("jndi");
                context = new InitialContext(props);
            }
            if (tcf == null) {
                tcf = (ConnectionFactory) context.lookup("ConnectionFactory");
            }
             if (commandTopic == null) {
                log.fine("lookup topic/control/command");
                commandTopic = (Topic) context.lookup("topic/control/command");
                
            }
            if (statusTopic == null) {
                log.fine("lookup topic/control/status");
                statusTopic = (Topic) context.lookup("topic/control/status");
                
            }
            if (logTopic == null) {
                log.fine("lookup topic/control/log");
                logTopic = (Topic) context.lookup("topic/control/log");
                
            }
            // Destroy all existing connections (just in case)
           
            
            
        } catch (NamingException e1) {
            e1.printStackTrace();
            throw new RuntimeException(e1);
//        } catch (JMException ex) {
//            log.error(TopicContextFactory.class.getName());
//            throw new RuntimeException(ex);
//        } catch (IOException ex) {
//            log.error(TopicContextFactory.class.getName());
//            throw new RuntimeException(ex);
        } 
    }
    
    public synchronized Session createSession(String agentName) throws JMSException{
        if (tcf == null){
            getTopicContext();
        }
        Connection connection = tcf.createConnection();
        connection.setClientID(agentName);
        connection.start();
        Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
        return session;
    }
    
    
    public synchronized Topic getCommandTopic() {
        if (commandTopic == null) {
            getTopicContext();
        }
        return commandTopic;
    }
    
    public synchronized Topic getStatusTopic() {
        if (statusTopic == null) {
            getTopicContext();
        }
        return statusTopic;
    }
    
    public synchronized Topic getLogTopic() {
        if (logTopic == null) {
            getTopicContext();
        }
        return logTopic;
    }
    
    public synchronized Topic getTopic(String topic){
        switch (topic){
            case "LOG":
                return getLogTopic();
            case "STATUS":
                return getStatusTopic();
            case "COMMAND":
                return getCommandTopic();
            default :
                return null;
        }
    }
    
    public MessageConsumer getSubscriber(Session session, String agentName, BusAccess busAccess, String messageSelector){
        try {
            switch (busAccess.getBus().ordinal()){
                case 0:
                return session.createConsumer(logTopic, messageSelector, false);
                case 1:
                return session.createConsumer(statusTopic, messageSelector, false);
                case 2:
                return session.createConsumer(commandTopic, messageSelector, false);
            }
            return null; // Todo : change that
        } catch (JMSException ex) {
            throw new RuntimeException(ex);
        }
    }
    
    
//    public MBeanServerConnection getMBeanServerConnection(){
//        if (mbsc == null){
//            getTopicContext();
//        }
//        return mbsc;
//    }
}
